==> haskell-bsb-http-chunked-0.0.0.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bsb-http-chunked
version: 0.0.0.2
id: bsb-http-chunked-0.0.0.2-FXxMM6P7f5t1P4df9hBSIz
key: bsb-http-chunked-0.0.0.2-FXxMM6P7f5t1P4df9hBSIz
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
stability: Provisional
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).
    .
    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.
category: Data, Network
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Data.ByteString.Builder.HTTP.Chunked
hidden-modules: Blaze.ByteString.Builder.Char8
                Blaze.ByteString.Builder.Compat.Write
                Blaze.ByteString.Builder.Internal.Write
abi: a3c79f775bb5029483fb696be4489401
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/bsb-http-chunked-0.0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/bsb-http-chunked-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/bsb-http-chunked-0.0.0.2
hs-libraries: HSbsb-http-chunked-0.0.0.2-FXxMM6P7f5t1P4df9hBSIz
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock
haddock-html: /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bsb-http-chunked-0.0.0.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bsb-http-chunked
version: 0.0.0.2
id: bsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg
key: bsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg
license: BSD-3-Clause
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
stability: Provisional
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).
    .
    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.
category: Data, Network
abi: 649acfe050cfb260f3fbbf1d4f8cbc2e
exposed: True
exposed-modules:
    Data.ByteString.Builder.HTTP.Chunked
hidden-modules: Blaze.ByteString.Builder.Char8
                Blaze.ByteString.Builder.Compat.Write
                Blaze.ByteString.Builder.Internal.Write
import-dirs: /usr/lib/ghc-8.4.2/site-local/bsb-http-chunked-0.0.0.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/bsb-http-chunked-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/bsb-http-chunked-0.0.0.2
hs-libraries: HSbsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
haddock-interfaces: /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock
haddock-html: /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
